California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 77 - REAPPORTIONMENT. INITIATIVE CONSTITUTIONAL AMENDMENT. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1275071 | CALIFORNIANS FOR FAIR ELECTIONS, YES ON PROPOSITION 77, WITH MAJOR FUNDING FROM CALIFORNIA BUSINESS PAC AND SBAC - PAC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1276320 | NO ON 77 - CALIFORNIANS FOR FAIR REPRESENTATION | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280778 | COMMITTEE FOR AN INDEPENDENT VOICE - YES ON 77! | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280977 | ASIAN PACIFIC AMERICANS FOR AN INFORMED CALIFORNIA, SPONSORED BY THE ASIAN LAW CAUCUS, A COMMITTEE AGAINST PROPOSITIONS 73, 74, 75, 76, AND 77 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1275062 | CALIFORNIANS FOR FAIR REDISTRICTING, YES ON PROPOSITION 77 | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1277456 | COMMITTEE TO PROTECT CALIFORNIA'S FUTURE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279513 | A COALITION OF LEGAL EXPERTS, FILMMAKERS, BUSINESSMEN, AND WORKING PEOPLE. MAJOR FUNDING BY SHANGRI-LA ENTERTAINMENT, LLC & AMERICAN FAMILY VOICES - NO ON 77 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279997 | FOR JUDICIAL RESTRAINT - NO ON 77 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1280140 | CALIFORNIANS AGAINST ARNOLD'S SPECIAL INTEREST ELECTION - NO ON 73, 74, 75, 76, 77 AND 78 AND YES ON 79 AND 80, SPONSORED BY WORKING ASSETS AND BALLOT INITIATIVE STRATEGY CENTER | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1279790 | REDISTRICT CALIFORNIA - YES ON 77, WITH MAJOR FUNDING PROVIDED BY STEVE POIZNER, POIZNER FOR INSURANCE COMMISSIONER & CALBUSPAC | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1281170 | NO ON 74, 75: FINANCED BY COUNCIL PRESIDENT ALEX PADILLA COMMITTEE | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1261406 | SCHWARZENEGGER'S CALIFORNIA RECOVERY TEAM, GOVERNOR | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1281358 | COMMON CAUSE COMMITTEE FOR PROPOSITION 77 | SUPPORT